<?php
/*
Plugin Name: Custom Checkout Fields for WooCommerce
Plugin URI: https://wpfactory.com/item/custom-checkout-fields-for-woocommerce/
Description: Add custom fields to WooCommerce checkout page.
Version: 1.3.0
Author: Algoritmika Ltd
Author URI: https://www.algoritmika.com
Text Domain: custom-checkout-fields-for-woocommerce
Domain Path: /langs
Copyright:  2019 Algoritmika Ltd.
WC tested up to: 3.8
License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Check if WooCommerce is active
$plugin = 'woocommerce/woocommerce.php';
if (
	! in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) &&
	! ( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
) {
	return;
}

if ( 'custom-checkout-fields-for-woocommerce.php' === basename( __FILE__ ) ) {
	// Check if Pro is active, if so then return
	$plugin = 'custom-checkout-fields-for-woocommerce-pro/custom-checkout-fields-for-woocommerce-pro.php';
	if (
		in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) ||
		( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
	) {
		return;
	}
}

// Constants
if ( ! defined( 'ALG_WC_CCF_VERSION' ) ) {
	define( 'ALG_WC_CCF_VERSION', '1.3.0' );
}
if ( ! defined( 'ALG_WC_CCF_ID' ) ) {
	define( 'ALG_WC_CCF_ID',      'alg_wc_ccf' );
}
if ( ! defined( 'ALG_WC_CCF_KEY' ) ) {
	define( 'ALG_WC_CCF_KEY',     'alg_wc_checkout_field' );
}

if ( ! function_exists( 'alg_wc_ccf_get_option' ) ) {
	/**
	 * alg_wc_ccf_get_option.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function alg_wc_ccf_get_option( $option, $default = false ) {
		return get_option( ALG_WC_CCF_ID . '_' . $option, $default );
	}
}

if ( ! function_exists( 'alg_wc_ccf_get_field_option' ) ) {
	/**
	 * alg_wc_ccf_get_field_option.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function alg_wc_ccf_get_field_option( $option, $field_nr, $default = false ) {
		return alg_wc_ccf_get_option( $option . '_' . $field_nr, $default );
	}
}

if ( ! class_exists( 'Alg_WC_CCF' ) ) :

/**
 * Main Alg_WC_CCF Class
 *
 * @class   Alg_WC_CCF
 * @version 1.3.0
 * @since   1.0.0
 */
final class Alg_WC_CCF {

	/**
	 * @var   Alg_WC_CCF The single instance of the class
	 * @since 1.0.0
	 */
	protected static $_instance = null;

	/**
	 * Main Alg_WC_CCF Instance
	 *
	 * Ensures only one instance of Alg_WC_CCF is loaded or can be loaded.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @static
	 * @return  Alg_WC_CCF - Main instance
	 */
	static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Alg_WC_CCF Constructor.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 * @access  public
	 * @todo    [feature] settings reset (options and/or order meta)
	 */
	function __construct() {

		// Set up localisation
		load_plugin_textdomain( 'custom-checkout-fields-for-woocommerce', false, dirname( plugin_basename( __FILE__ ) ) . '/langs/' );

		// Pro
		if ( 'custom-checkout-fields-for-woocommerce-pro.php' === basename( __FILE__ ) ) {
			require_once( 'includes/pro/class-alg-wc-ccf-pro.php' );
		}

		// Include required files
		$this->includes();

		// Admin
		if ( is_admin() ) {
			$this->admin();
		}
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function includes() {
		// Functions
		require_once( 'includes/alg-wc-ccf-functions.php' );
		// Core
		$this->core = require_once( 'includes/class-alg-wc-ccf-core.php' );
	}

	/**
	 * admin.
	 *
	 * @version 1.3.0
	 * @since   1.1.0
	 */
	function admin() {
		// Action links
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'action_links' ) );
		// Settings
		add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_woocommerce_settings_tab' ) );
		require_once( 'includes/settings/alg-wc-ccf-options.php' );
		require_once( 'includes/settings/class-alg-wc-ccf-settings-section.php' );
		require_once( 'includes/settings/class-alg-wc-ccf-settings-field.php' );
		$this->settings = array();
		$this->settings['general'] = require_once( 'includes/settings/class-alg-wc-ccf-settings-general.php' );
		for ( $i = 1; $i <= apply_filters( 'alg_wc_ccf_total_fields', 1 ); $i++ ) {
			$this->settings[ 'field_' . $i ] = new Alg_WC_CCF_Settings_Field( $i );
		}
		// Version update
		if ( alg_wc_ccf_get_option( 'version', '' ) !== ALG_WC_CCF_VERSION ) {
			add_action( 'admin_init', array( $this, 'version_update' ) );
		}
	}

	/**
	 * Show action links on the plugin screen.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 * @param   mixed $links
	 * @return  array
	 */
	function action_links( $links ) {
		$custom_links = array();
		$custom_links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=' . ALG_WC_CCF_ID ) . '">' . __( 'Settings', 'woocommerce' ) . '</a>';
		if ( 'custom-checkout-fields-for-woocommerce.php' === basename( __FILE__ ) ) {
			$custom_links[] = '<a target="_blank" href="https://wpfactory.com/item/custom-checkout-fields-for-woocommerce/">' .
				__( 'Unlock All', 'custom-checkout-fields-for-woocommerce' ) .
			'</a>';
		}
		return array_merge( $custom_links, $links );
	}

	/**
	 * Add Custom Checkout Fields settings tab to WooCommerce settings.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function add_woocommerce_settings_tab( $settings ) {
		$settings[] = require_once( 'includes/settings/class-alg-wc-settings-ccf.php' );
		return $settings;
	}

	/**
	 * version_update.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function version_update() {
		update_option( ALG_WC_CCF_ID . '_' . 'version', ALG_WC_CCF_VERSION );
	}

	/**
	 * Get the plugin url.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  string
	 */
	function plugin_url() {
		return untrailingslashit( plugin_dir_url( __FILE__ ) );
	}

	/**
	 * Get the plugin path.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  string
	 */
	function plugin_path() {
		return untrailingslashit( plugin_dir_path( __FILE__ ) );
	}

}

endif;

if ( ! function_exists( 'alg_wc_custom_checkout_fields' ) ) {
	/**
	 * Returns the main instance of Alg_WC_CCF to prevent the need to use globals.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  Alg_WC_CCF
	 */
	function alg_wc_custom_checkout_fields() {
		return Alg_WC_CCF::instance();
	}
}

alg_wc_custom_checkout_fields();
